<?php

namespace App;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;

class Admission extends Model
{
    protected $table = 'admissions';
    
    protected $fillable = array(
        'name',
        'name_en',
        'year',
        'dv_issue',
        'dv_date',
        'end_date',
        'message',
        'message_en'
    );

    public $timestamps = true;

    const STATUS_INACTIVE = 0;
    const STATUS_PENDING = 1;
    const STATUS_ACTIVE = 2;
    const STATUS_EXPIRED = 3;

    public function competitions(){
        return $this->hasMany('App\AdmissionCompetition','admission_id','id');
    }

    public function approvedCompetitions(){
        return $this->hasMany('App\AdmissionCompetition','admission_id','id')
            ->where('status','=',AdmissionCompetition::STATUS_APPROVED)
            ->orWhere('status','=',AdmissionCompetition::STATUS_ACTIVE);
    }

    public function status(){
        if(strlen($this->dv_issue) < 1 || $this->dv_date == 0)
            return Admission::STATUS_INACTIVE;
        if($this->dv_date >= Carbon::now())
            return Admission::STATUS_PENDING;
        if($this->dv_date < Carbon::now() && $this->end_date > Carbon::now())
            return Admission::STATUS_ACTIVE;
        if($this->end_date < Carbon::now())
            return Admission::STATUS_EXPIRED;
    }


}
