<?php

namespace App;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;

class AdmissionCompetition extends Model
{
    protected $table = 'admission_competitions';

    protected $fillable = array(
        'guid',
        'specialty_id',
        'department_id',
        'edu_form_id',
        'finance_form_id',
        'scientific_advisor_id',
        'secondary_scientific_advisor_id',
        'user',
        'user_type',
        'status',
        'admission_id'
    );

    public $timestamps = true;

    const STATUS_NEEDS_INFO = 0;
    const STATUS_AWAITING_APPROVAL = 1;
    const STATUS_APPROVED = 2;
    const STATUS_ACTIVE = 3;
    const STATUS_EXPIRED = 4;
    const STATUS_REJECTED = 5;

    public function specialty(){
        return $this->belongsTo('App\Specialty','specialty_id','id');
    }

    public function department(){
        return $this->belongsTo('App\Department','department_id','id');
    }

    public function scientific_advisor(){
        return $this->belongsTo('App\ScientificAdvisor','scientific_advisor_id','id');
    }

    public function edu_form(){
        return $this->belongsTo('App\EduForm','edu_form_id','id');
    }

    public function finance_form(){
        return $this->belongsTo('App\FinanceForm','finance_form_id','id');
    }

    public function secondary_scientific_advisor(){
        return $this->belongsTo('App\ScientificAdvisor','secondary_scientific_advisor_id','id');
    }

    public function admission(){
        return $this->belongsTo('App\Admission','admission_id','id');
    }

    public function userObj(){
        switch($this->user_type){
            case 'advisor':
                return $this->belongsTo('App\ScientificAdvisor','user','id');
                break;
            default:
                return $this->belongsTo('App\User','user','id');
                break;
        }
    }

    public  function files(){
        return $this->hasMany('App\FileRegistry','competition_id','id');
    }

    public function registerFile($filename,$type,$size,$doctype){
        return FileRegistry::create(array(
            'filename' => Carbon::now()->day.Carbon::now()->month.Carbon::now()->year.'_'.Carbon::now()->hour.Carbon::now()->minute.Carbon::now()->second.'_'.$filename,
            'original_filename' => $filename,
            'type' => $type,
            'size' => $size,
            'competition_id' => $this->id,
            'document_type' => $doctype
        ));
    }
}
