<?php

namespace App;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Lang;
use Illuminate\Support\Facades\Mail;
use Nathanmac\GUID\GUID;

class ApplicationForm extends Model
{
    protected $table = 'application_forms';

    protected $fillable = array(
        'candidate_id',
        'competition_id',
        'diploma_id',
        'graduation_date',
        'degree_name',
        'degree_gpa',
        'degree_def_gpa',
        'foreign_language',
        'status',
        'guid',
        'notification_id',
        'grade_exam',
        'grade_exam_language',
        'enrollment_date',
        'enrollment_deadline_date',
        'protocol'
    );

    const STATUS_PENDING = 0;
    const STATUS_TAKE_EXAM = 1;
    const STATUS_NOTIFICATION_SENT = 2;
    const STATUS_NOTIFIED = 3;
    const STATUS_APPROVED = 4;
    const STATUS_DECLINED = 5;
    const STATUS_EXPIRED  = 6;
    const STATUS_PHD = 7;

    public $timestamps = true;

    public function competition(){
        return $this->belongsTo('App\AdmissionCompetition','competition_id','id');
    }

    public function candidate(){
        return $this->belongsTo('App\Candidate','candidate_id','id');
    }

    public function files(){
        return $this->hasMany('App\FileRegistry','applicationform_id','id');
    }

    public function getStatus(){
        return Lang::get('frontend.applicationform_status'.$this->status);
    }

    public function getStatusCSSClass(){
        switch($this->status){
            default:
                return 'label label-default';
                break;

            case ApplicationForm::STATUS_PENDING:
                return 'label label-primary';
                break;

            case ApplicationForm::STATUS_TAKE_EXAM:
                return 'label label-info';
                break;

            case ApplicationForm::STATUS_NOTIFIED:
                return 'label label-info';
                break;

            case ApplicationForm::STATUS_NOTIFICATION_SENT:
                return 'label label-warning';
                break;

            case ApplicationForm::STATUS_APPROVED:
                return 'label label-success';
                break;

            case ApplicationForm::STATUS_DECLINED:
                return 'label label-danger';
            break;

            case ApplicationForm::STATUS_EXPIRED:
                return 'label label-danger';
                break;
        }
    }

    public function sendExamNotification(){
        Carbon::setToStringFormat(Lang::get('email.timeformat'));
        $examdate = Carbon::parse($this->date_exam);
        $flexamdate = Carbon::parse($this->date_exam_language);
        $this->notification_id = str_random(16);
        $this->save();
            Mail::send('email.exam_notification',
            array(
                'pa' => $this->competition->specialty->professional_area->code." ".$this->competition->specialty->professional_area->name,
                'specialty'=> $this->competition->specialty->name,
                'examdate'=>$examdate,
                'examplace'=>$this->place_exam,
                'flexamdate'=>$flexamdate,
                'flexamplace'=>$this->place_exam_language,
                'link' => url('confirm/exams').'/'.$this->notification_id),
            function ($m) {
                //todo fix email
            $m->from(Lang::get('email.address_from'), 'PHD System');
            $m->to($this->candidate->email)->subject(Lang::get('email.exam_notification_subject'));
        });

    }

    public function registerFile($filename,$type,$size,$doctype){
        return FileRegistry::create(array(
            'filename' => Carbon::now()->day.Carbon::now()->month.Carbon::now()->year.'_'.Carbon::now()->hour.Carbon::now()->minute.Carbon::now()->second.'_'.$filename,
            'original_filename' => $filename,
            'type' => $type,
            'size' => $size,
            'applicationform_id' => $this->id,
            'document_type' => $doctype
        ));
    }

}
