<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Foundation\Auth\User as Authenticatable;

class Candidate extends Authenticatable
{
    protected $table = 'candidates';

    protected $fillable = array(
        'EGN',
        'name',
        'surname',
        'last_name',
        'gender',
        'citizenship',
        'birthplace',
        'home_address',
        'permanent_address',
        'home_phone',
        'mobile_phone',
        'office_phone',
        'email',
        'password',
        'workplace',
        'edu_institution_name',
        'degree_qualification',
        'degree_name',
        'graduation_date',
        'degree_gpa',
        'degree_def_gpa',
        'status',
        'edu_form_id',
        'finance_form_id',
        'department_id',
        'specialty_id',
        'scientific_advisor',
        'scientific_advisor_sec',
        'foreign_language',
        'diploma_id',
        'linked_phd'
    );

    public $timestamps = true;

    public function specialty(){
        return $this->belongsTo('App\Specialty','specialty_id','id');
    }

    public function department(){
        return $this->belongsTo('App\Department','department_id','id');
    }

    public function edu_form(){
        return $this->belongsTo('App\EduForm','edu_form_id','id');
    }

    public function degreeQualification(){
        return $this->belongsTo('App\DegreeQualification','degree_qualification','id');
    }

    public function phd(){
        return $this->belongsTo('App\PhDStudent','linked_phd','id');
    }

    public function getStatus(){
        switch($this->status){
            default:
                return '?!?';
                break;

            case '0':
                return 'кандидат';
                break;
        }
    }

    public function hasAppliedFor(AdmissionCompetition $competition){
        return ApplicationForm::where('candidate_id',$this->id)->where('competition_id',$competition->id)->count() > 0;
    }

    public function applicationForms(){
        return $this->hasMany('App\ApplicationForm','candidate_id','id');
    }
}
