<?php
/**
 * Created by PhpStorm.
 * User: Pavel
 * Date: 2016-05-21
 * Time: 10:58 PM
 */

namespace App;

use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Lang;

class Helpers
{

    public static function getUser()
    {
        if(Auth::guard('candidates')->user() != null){
            return Auth::guard('candidates')->user();
        } else if(Auth::guard('phdstudents')->user() != null) {
            return Auth::guard('phdstudents')->user();
        } else if(Auth::guard('advisors')->user() != null){
            return Auth::guard('advisors')->user();
        } else if(Auth::user() != null){
            return Auth::user();
        }
        return null;
    }

    public static function getUserType()
    {
        if(Auth::guard('candidates')->user() != null){
            return 'candidate';
        } else if(Auth::guard('phdstudents')->user() != null) {
            return 'phd';
        } else if(Auth::guard('advisors')->user() != null){
            return 'advisor';
        } else if(Auth::user() != null){
            return 'admin';
        }
        return 'unknown';
    }

    public static function getLogoutLink(){
        if(self::getUser() instanceof Candidate) {
            return (string)url('auth/logout/candidate');
        } else if(self::getUser() instanceof PhDStudent){
            return (string) url('auth/logout/phdstudent');
        } else if(self::getUser() instanceof User){
            return (string) url('auth/logout');
        } else if(self::getUser() instanceof ScientificAdvisor){
            return (string) url('auth/logout/advisor');
        }
        return (string) url('');
    }

    public static function getProfileLink(){
        if(self::getUser() instanceof Candidate){
            return (string) url('profile');
        }
        else if(self::getUser() instanceof PhDStudent){
            return (string) url('phdstudent');
        }
        else if(self::getUser() instanceof ScientificAdvisor){
            return (string) url('advisor');

        } else if(self::getUser() instanceof User) {
            return (string)url('admin');
        }

        return (string) url('');
    }

    public static function getUserName($user=null){
        if($user==null) {$user=self::getUser();}
        if($user instanceof Candidate){
            return $user->name . " " . $user->last_name;
        } else if($user instanceof PhDStudent){
            return $user->name . " " . $user->last_name;
        } else if($user instanceof User){
            return $user->name;
        } else if($user instanceof ScientificAdvisor){
            return $user->buildName();
        }
    }

    public static function getCompetitionStatus($status){
        return Lang::get('advisorcp.status'.$status);
    }

    public static function getCompetitionStatusCSSClass($status){
        switch($status){
            default:
                return 'label label-default';
                break;

            case AdmissionCompetition::STATUS_NEEDS_INFO:
            case AdmissionCompetition::STATUS_REJECTED:
                case AdmissionCompetition::STATUS_EXPIRED:
                return 'label label-danger';
                break;

            case AdmissionCompetition::STATUS_APPROVED:
                return 'label label-success';
                break;

            case AdmissionCompetition::STATUS_ACTIVE:
                return 'label label-primary';
                break;
        }
    }

    public static function toMB($size){
        return number_format((intval($size)/1024)/1024,2);
    }

    public static function friendlyDoctype($doctype){
        return Lang::get('advisorcp.filetype_'.$doctype);
    }

    public static function isStatus($status){
        return $status == AdmissionCompetition::STATUS_NEEDS_INFO ||
        $status == AdmissionCompetition::STATUS_AWAITING_APPROVAL ||
        $status == AdmissionCompetition::STATUS_APPROVED ||
        $status == AdmissionCompetition::STATUS_ACTIVE ||
        $status == AdmissionCompetition::STATUS_EXPIRED ||
        $status == AdmissionCompetition::STATUS_REJECTED;
    }
    
    public static function getAdmissionStatusCSSClass($status){
        switch($status){
            default:
                return 'label label-default';
            break;
            
            case Admission::STATUS_PENDING:
                return 'label label-warning';
                break;

            case Admission::STATUS_INACTIVE:
                return 'label label-danger';
                break;

            case Admission::STATUS_ACTIVE:
                return 'label label-success';
                break;

            case Admission::STATUS_EXPIRED:
                return 'label label-primary';
                break;
        }
    }

    public static function getAdmissionStatus($status){
        return Lang::get('frontend.admission_status'.$status);
    }

    public static function html2word($html,$filename='document',$landscape = false){
        header( 'Content-Type: application/msword' );
        header("Content-disposition: attachment; filename=".$filename .date("d-m-Y").".doc");
        /*
        header("Content-type: application/vnd.ms-word");
        header("Content-disposition: attachment; filename=" .date("Y-m-d").".rtf");
        */
        //$html = preg_replace('%/[^\\s]+\\.(jpg|jpeg|png|gif)%i', '\\0', $html);

        print "<html xmlns:v=\"urn:schemas-microsoft-com:vml\"";
        print "xmlns:o=\"urn:schemas-microsoft-com:office:office\"";
        print "xmlns:w=\"urn:schemas-microsoft-com:office:word\"";
        print "xmlns=\"http://www.w3.org/TR/REC-html40\">";
        print("<style>");
        print("@page Section1 {size:21cm 29.7cm;margin: 1.5cm 1.5cm 1.5cm 1.5cm;mso-header-margin:.5in;mso-footer-margin:.5in;mso-paper-source:0;}");
        print("div.Section1 {page:Section1;}");
        print("@page Section2 {size: 29.7cm 21cm;mso-page-orientation:landscape;margin: 1.5cm 1.5cm 1.5cm 1.5cm;mso-header-margin:.5in;mso-footer-margin:.5in;mso-paper-source:0;}");
        print("div.Section2 {page:Section2;}");
        print("</style>");
        print "<xml>
     <w:WordDocument>
      <w:View>Print</w:View>
      <w:DoNotHyphenateCaps/>
      <w:PunctuationKerning/>
      <w:DrawingGridHorizontalSpacing>9.35 pt</w:DrawingGridHorizontalSpacing>
      <w:DrawingGridVerticalSpacing>9.35 pt</w:DrawingGridVerticalSpacing>
      <w:body>
      <w:sectPr>
        <w:pgSz w:w=\"15840\" w:h=\"12240\" w:orient=\"landscape\"/>
      </w:sectPr>
      </w:body>
     </w:WordDocument>
    </xml>
    ";
        if($landscape)
        print('<div class="Section2">');
        else print('<div class="Section1">');
        echo($html);
        print("</div>");
        exit;
    }

    public static function old($formvalue,$value,$object){
        if(strlen(old($formvalue))>1)
            return old($formvalue);
        else return $object->$value;

    }

    public static function setPassword($user,$password){
        $user->password = bcrypt($password);
        $user->save();
        return $user->password;
    }
}