<?php

namespace App\Http\Controllers\Admin;

use App\ApplicationForm;
use App\Helpers;
use App\PhDStudent;
use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Input;

class ApplicationFormController extends Controller
{
    public function getIndex()
    {
        return view('admin.application_forms')->with(array('user'=>Auth::user(),'application_forms'=>ApplicationForm::all()));
    }

    public function view($id){
        $applicationform = ApplicationForm::where('id',$id)->first();
        if(!$applicationform) return back();
        return view('admin.application_form')->with(array('user'=>Auth::user(),'af'=>$applicationform));
    }

    public function setExam(){
        $examdate = Input::get('examDate');
        $flexamdate = Input::get('flExamDate');
        $examplace = Input::get('examPlace');
        $flexamplace = Input::get('flExamPlace');
        if(count(Input::get('cbform')) > 0)
        foreach(Input::get('cbform') as $id){
            $af = ApplicationForm::where('id',$id)->first();
            if($af != null){
                $af->status = ApplicationForm::STATUS_TAKE_EXAM;
                $notify = false;
                if(strlen($examdate) > 0){
                    $af->date_exam = $examdate;
                    $af->place_exam = $examplace;
                    $notify = true;

                }
                if(strlen($flexamdate) > 0){
                    $af->date_exam_language = $flexamdate;
                    $af->place_exam_language = $flexamplace;
                    $notify = true;
                }
                
                $af->save();

                if($notify){
                    //todo notify candidate by email
                    $af->sendExamNotification();
                    $af->status = ApplicationForm::STATUS_NOTIFICATION_SENT;
                    $af->save();
                }
            }
        }

        return back();
    }

    public function updateGrades(Request $request){
        
        $this->validate($request,array(
            'cGrade' => 'numeric|min:2|max:6',
            'cGradeLanguage' => 'numeric|min:2|max:6'
        ));

        $af = ApplicationForm::where('id',Input::get('fid'))->first();

        if($af) {

            $cGrade = floatval(Input::get('cGrade'));
            $cGradeLanguage = floatval(Input::get('cGradeLanguage'));

            if ($cGrade >= 2 && $cGrade <= 6) {
                $af->grade_exam = $cGrade;
                $af->save();
            }

            if($cGradeLanguage >= 2 && $cGradeLanguage <= 6){
                $af->grade_exam_language = $cGradeLanguage;
                $af->save();
                
                if($af->grade_exam >= 5 && $af->grade_exam_language >= 4){
                    //todo find a way not to hardcode this - config, env or db settings
                    $af->status = ApplicationForm::STATUS_APPROVED;
                    $af->save();
                    //todo send a notification
                } else if($af->grade_exam < 4.5 && $af->grade_exam_language < 4.5){
                    $af->status = ApplicationForm::STATUS_DECLINED;
                    $af->save();
                    //todo send a notification
                }
            }
        }

        return back();
    }

    public function enroll($id,Request $request){
        $this->validate($request,array(
            'enrollmentDate' => 'date',
            'termDate' => 'date',
        ));

        $af = ApplicationForm::where('id',$id)->first();
        if($af){
            $af->enrollment_date = Input::get('enrollmentDate');
            $af->enrollment_deadline_date = Input::get('termDate');
            $af->protocol = Input::get('protocolNo');
            $af->save();

            if($af->enrollment_date > 0 && $af->enrollment_deadline_date > 0 && strlen($af->protocol > 0) && strlen(Input::get('orderNo')) > 0){
                $phd = PhDStudent::create(
                    array(
                        'EGN' => $af->candidate->EGN,
                        'name'=> $af->candidate->name,
                        'surname' => $af->candidate->surname,
                        'last_name' => $af->candidate->last_name,
                        'gender' => $af->candidate->gender,
                        'citizenship' => $af->candidate->citizenship,
                        'birthplace' => $af->candidate->birthplace,
                        'home_address' => $af->candidate->home_address,
                        'permanent_address' => $af->candidate->permanent_address,
                        'home_phone' => $af->candidate->home_phone,
                        'mobile_phone' => $af->candidate->mobile_phone,
                        'office_phone' => $af->candidate->office_phone,
                        'email' => $af->candidate->email,
                        'workplace' => $af->candidate->workplace,
                        'edu_institution_name' => $af->candidate->edu_institution_name,
                        'degree_qualification' => $af->candidate->degree_qualification,
                        'degree_name' => $af->degree_name,
                        'diploma_id' => $af->diploma_id,
                        'graduation_date' => $af->graduation_date,
                        'degree_gpa' => $af->degree_gpa,
                        'degree_def_gpa' => $af->degree_def_gpa,
                        'status' => 0,
                        'edu_form_id' => $af->competition->edu_form_id,
                        'finance_form_id' => $af->competition->finance_form_id,
                        'department_id' => $af->competition->department_id,
                        'specialty_id' => $af->competition->specialty_id,
                        'scientific_advisor' => $af->competition->scientific_advisor_id,
                        'scientific_advisor_sec' => $af->competition->secondary_scientific_advisor_id,
                        'foreign_language' => $af->foreign_language,
                        'order_document' => Input::get('orderNo'),
                        'order_document_date' => Input::get('orderDate'),
                        'enrollment_date' => $af->enrollment_date,
                        'term_deadline_date' => $af->enrollment_deadline_date
                    )
                );

                $af->candidate->update(array(
                    'linked_phd' => $phd->id
                ));
                $af->status = ApplicationForm::STATUS_PHD;
                $af->save();
            }
        }

        return back();
    }

    public function generateOrder($id){
        Helpers::html2word(view('forms.enrollment_doc')->with(array('af'=>ApplicationForm::where('id',$id)->first())),'zapoved');
    }
}
