<?php

namespace App\Http\Controllers\Admin;

use App\Candidate;
use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class CandidateController extends Controller
{
    public function getIndex(){
        return view('admin.candidates')->with(['phdstudents'=>Candidate::all(),'user'=>Auth::user()]);
    }

    public function createForm(){
        return view('admin.forms.candidate')->with(['user'=>Auth::user()]);
    }

    public function create(Request $request){
        $this->validate($request,[
            'psFirstName' => 'required',
            'psSurname' => 'required',
            'psLastName' => 'required',
            'psUIN' => 'required|size:10',
            'psGender' => 'required|in:m,f',
            'psCitizenship' => 'required',
            'psBirthplace' => 'required',
            'psHomeAddress' => 'required',
            'psPermanentAddress' => 'required',
            'psHomePhone' =>'required_without_all:psMobilePhone,psOfficePhone',
            'psMobilePhone' => 'required_without_all:psHomePhone,psOfficePhone',
            'psOfficePhone' => 'required_without_all:psHomePhone,psMobilePhone',
            'psEmail' => 'required|email',
            //'psWorkplace' => 'required',
            'psEduInstitution' => 'required',
            'psDegreeQualification' => 'required',
            'psDegreeName' => 'required',
            'psGraduationDate' => 'required|date',
            'psDegreeGPA' => 'required|numeric|min:2|max:6',
            'psDegreeGPADef' => 'required|numeric|min:2|max:6',
            'psEduForm' => 'required',
            'psFinanceForm' => 'required',
            'psDepartment' => 'required|exists:departments,id',
            'psPA' => 'required|exists:professional_areas,code',
            'psSpec' => 'required|exists:specialties,id',
            'psSA1' => 'required|exists:scientific_advisors,id',
            'psSA2' => 'exists:scientific_advisors,id',
            'psForeignLanguage' => 'required'
        ]);

        $ps = Candidate::create([
            'EGN' => Input::get('psUIN'),
            'name'=> Input::get('psFirstName'),
            'surname' => Input::get('psSurname'),
            'last_name' =>Input::get('psLastName'),
            'gender' => Input::get('psGender'),
            'citizenship' => Input::get('psCitizenship'),
            'birthplace' => Input::get('psBirthplace'),
            'home_address' => Input::get('psHomeAddress'),
            'permanent_address' => Input::get('psPermanentAddress'),
            'home_phone' => Input::get('psHomePhone'),
            'mobile_phone' => Input::get('psMobilePhone'),
            'office_phone' => Input::get('psOfficePhone'),
            'email' => Input::get('psEmail'),
            'workplace' => Input::get('psWorkplace'),
            'edu_institution_name' => Input::get('psEduInstitution'),
            'degree_qualification' => Input::get('psDegreeQualification'),
            'degree_name' => Input::get('psDegreeName'),
            'graduation_date' => Input::get('psGraduationDate'),
            'degree_gpa' => Input::get('psDegreeGPA'),
            'degree_def_gpa' => Input::get('psDegreeGPADef'),
            'status' => 0,
            'edu_form_id' => Input::get('psEduForm'),
            'finance_form_id' => Input::get('psFinanceForm'),
            'department_id' => Input::get('psDepartment'),
            'specialty_id' => Input::get('psSpec'),
            'scientific_advisor' => Input::get('psSA1'),
            'scientific_advisor_sec' => Input::get('psSA2'),
            'foreign_language' => Input::get('psForeignLanguage')

        ]);

        return redirect('admin/candidates');
    }


    public function view($id){
        $candidate = Candidate::findOrFail($id);
        return view('admin.candidate')->with(array('user'=>Auth::user(),'candidate'=>$candidate));
    }
}
