<?php

namespace App\Http\Controllers;

use App\Admission;
use App\AdmissionCompetition;
use App\ApplicationForm;
use App\Helpers;
use Carbon\Carbon;
use Illuminate\Http\Request;

use App\Http\Requests;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Input;
use Nathanmac\GUID\GUID;
use Symfony\Component\Console\Helper\Helper;

class AdmissionController extends Controller
{
    public function getIndex(){
        return view('admissions')->with(array('active'=>Admission::where('dv_date', '<=', Carbon::now())
            ->where('end_date','>=',Carbon::now())
            ->whereNotNull('dv_issue')
            ->where('dv_issue','<>','')
            ->get()));
    }
    
    public function applicationForm($id){
        return view('forms.application_form')->with(array('competition'=>AdmissionCompetition::where('id',$id)->first()));
    }
    
    public function processApplication($id, Request $request){

        $competition = AdmissionCompetition::where('id',$id)->first(); // todo check if active or not applied to

        $this->validate($request,array(
            'fCV' => 'required|mimes:pdf,doc,docx',
            'fDiplomaBsc' => 'required|mimes:pdf,doc,docx',
            'fDiplomaMsc' => 'required|mimes:pdf,doc,docx',
            'fMedical' => 'required'
        ));
        $guid = new GUID();
        $application = ApplicationForm::create(array(
            'candidate_id' => Helpers::getUser()->id,
            'competition_id' => $competition->id,
            'diploma_id' => Helpers::getUser()->diploma_id,
            'graduation_date' => Helpers::getUser()->graduation_date,
            'degree_name' => Helpers::getUser()->degree_name,
            'degree_gpa' => Helpers::getUser()->degree_gpa,
            'degree_def_gpa' => Helpers::getUser()->degree_def_gpa,
            'foreign_language' => Helpers::getUser()->foreign_language,
            'status' => ApplicationForm::STATUS_PENDING,
            'guid' => $guid->generate()
        ));

        if($application){
            $dirpath = base_path().DIRECTORY_SEPARATOR.'storage'.DIRECTORY_SEPARATOR.'afdocs'.DIRECTORY_SEPARATOR.$application->guid;
            $dir = true;
            if(!File::exists($dirpath)){
                $dir = File::makeDirectory($dirpath, 0775, true);

                $f = $application->registerFile(
                    Input::file('fCV')->getClientOriginalName(),
                    Input::file('fCV')->getClientOriginalExtension(),
                    Input::file('fCV')->getSize(),
                    'cv');
                Input::file('fCV')->move($dirpath, $f->filename);

                $f = $application->registerFile(
                    Input::file('fDiplomaBsc')->getClientOriginalName(),
                    Input::file('fDiplomaBsc')->getClientOriginalExtension(),
                    Input::file('fDiplomaBsc')->getSize(),
                    'diploma_bsc');
                Input::file('fDiplomaBsc')->move($dirpath, $f->filename);

                $f = $application->registerFile(
                    Input::file('fDiplomaMsc')->getClientOriginalName(),
                    Input::file('fDiplomaMsc')->getClientOriginalExtension(),
                    Input::file('fDiplomaMsc')->getSize(),
                    'diploma_msc');
                Input::file('fDiplomaMsc')->move($dirpath, $f->filename);

                $f = $application->registerFile(
                    Input::file('fMedical')->getClientOriginalName(),
                    Input::file('fMedical')->getClientOriginalExtension(),
                    Input::file('fMedical')->getSize(),
                    'medical');
                Input::file('fMedical')->move($dirpath, $f->filename);


            }

            return back();
        }

        else return redirect('/profile/failure');
    }

    public function getCompetitionInfo($id){
        return view('competition')->with(array('competition'=>AdmissionCompetition::where('id',$id)->first()));
    }

    public function confirmExamNotification($id){
        $af = ApplicationForm::where('notification_id',$id)->first();
        if($af){
            if($af->status != ApplicationForm::STATUS_PHD)
            $af->status = ApplicationForm::STATUS_NOTIFIED;
            $af->notification_id = '';
            $af->save();
            //todo save into some sort of log

            return view('email.receipt_confirm');
        }

        return redirect(url(''));
    }
}
