<?php

namespace App\Http\Controllers;

use App\AdmissionCompetition;
use App\ApplicationForm;
use App\Helpers;
use App\PhDStudent;
use Illuminate\Http\Request;

use App\Http\Requests;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Lang;
use Nathanmac\GUID\GUID;

class AdvisorPanelController extends Controller
{
    //
    public function getIndex()
    {
        return view('advisorcp.index')->with(array(
            'title' => Lang::get('advisorcp.title'),
            'competitions' => AdmissionCompetition::take(10)->where('user_type','advisor')->where('user',Helpers::getUser()->id)->get(),
            'phdstudents' => PhDStudent::where('scientific_advisor',Helpers::getUser()->id)->orWhere('scientific_advisor_sec',Helpers::getUser()->id)->orderBy('enrollment_date','desc')->get(),
    )
        );
    }

    public function getCompetition($id){
        return view('advisorcp.competition')->with(array('competition'=>AdmissionCompetition::where('id',$id)->where('user',Helpers::getUser()->id)->where('user_type','advisor')->first()));
    }

    public function createCompetitionForm(){
        return view('advisorcp.forms.competition')->with(array('title'=>Lang::get('advisorcp.competition_create_pagetitle')));
    }

    public function createCompetition(Request $request){
        $this->validate($request,array(
            'compPA'=>'required',
            'compSpec' => 'required',
            'compDepartment' => 'required',
            'compEduForm' => 'required',
            'compFinanceForm' => 'required',
            'compSA1' => 'required',
            'compSA2' => 'different:compSA1'
        ));
        $guid = new GUID();
        $competition = AdmissionCompetition::create(array(
            'specialty_id' => Input::get('compSpec'),
            'department_id' => Input::get('compDepartment'),
            'edu_form_id' => Input::get('compEduForm'),
            'finance_form_id' => Input::get('compFinanceForm'),
            'scientific_advisor_id' => Helpers::getUser()->id, //we don't care about compSA1, but it's still there
            'secondary_scientific_advisor_id' => Input::get('compSA2'),
            'user' => Helpers::getUser()->id,
            'user_type' => 'advisor',
            'guid' => $guid->generate(),
            'status' => 0
        ));

        if($competition instanceof AdmissionCompetition){
            return redirect('advisor/competitions/documentation/'.$competition->id);
        } else{
            return 'error!';
        }
    }

    public function competitionDocumentationForm($id){
        return view('advisorcp.forms.competition_documentation');
    }

    public function postCompetitionDocumentationForm(Request $request, $id){
        $this->validate($request,array(
            'fConspect' => 'required|mimes:pdf,doc,docx',
            'fProject' => 'required|mimes:pdf,doc,docx',
            'fProtocol' => 'required|mimes:pdf,doc,docx'
        ));
        $competition = AdmissionCompetition::where('id',$id)->first();
        $dirpath = base_path().DIRECTORY_SEPARATOR.'storage'.DIRECTORY_SEPARATOR.'competitiondocs'.DIRECTORY_SEPARATOR.$competition->guid;
        $dir = true;
        if(!File::exists($dirpath)){
            $dir = File::makeDirectory($dirpath, 0775, true);
        }

        if($dir){
            

            $f = $competition->registerFile(Input::file('fConspect')->getClientOriginalName(),Input::file('fConspect')->getClientOriginalExtension(),Input::file('fConspect')->getSize(),'conspect');
            Input::file('fConspect')->move($dirpath, $f->filename);

            $f = $competition->registerFile(Input::file('fProject')->getClientOriginalName(),Input::file('fProject')->getClientOriginalExtension(),Input::file('fProject')->getSize(),'project');
            Input::file('fProject')->move($dirpath, $f->filename);

            $f = $competition->registerFile(Input::file('fProtocol')->getClientOriginalName(),Input::file('fProtocol')->getClientOriginalExtension(),Input::file('fProtocol')->getSize(),'protocol');
            Input::file('fProtocol')->move($dirpath, $f->filename);

            $competition->status = 1;
            $competition->save();

            return redirect('advisor');

        } else abort(500,'Storage directory error.');

    }

    public function getCompetitionCandidates($id){
        $comp = AdmissionCompetition::where('id',$id)->first();
        if($comp && ($comp->scientific_advisor->id = Helpers::getUser()->id || ($comp->scientific_advisor_sec && $comp->scientific_advisor_sec->id == Helpers::getUser()->id) )){
            return view('advisorcp.application_forms')->with(array('application_forms'=>ApplicationForm::where('competition_id',$id)->get()));
        }
        else return back();


    }

    public function getApplicationForm($id){
        return view('application_form')->with(array('af'=>ApplicationForm::where('id',$id)->first()));
    }
    
    public function viewPhdStudent($id){
        return view('phdcp.index')->with(array('phd'=>PhDStudent::where('id',$id)->first()));
    }
}
