<?php

namespace App\Http\Controllers;

use App\AdvisorRegistrationCode;
use App\ApplicationForm;
use App\Candidate;
use App\Helpers;
use App\ScientificAdvisor;
use Illuminate\Http\Request;

use App\Http\Requests;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Lang;

class UserController extends Controller
{
    public function createCandidateForm(){
        return view('forms.candidate_register');
    }

    public function createCandidate(Request $request){
        $this->validate($request,[
            'psEmail' => 'required|email|unique:candidates,email',
            'psPassword' => 'required|min:6',
            'psPassword2' => 'required|same:psPassword',
            'psFirstName' => 'required',
            'psSurname' => 'required',
            'psLastName' => 'required',
            'psUIN' => 'required|size:10|unique:candidates,EGN',
            'psGender' => 'required|in:m,f',
            'psCitizenship' => 'required',
            'psBirthplace' => 'required',
            'psHomeAddress' => 'required',
            'psPermanentAddress' => 'required',
            'psHomePhone' =>'required_without_all:psMobilePhone,psOfficePhone',
            'psMobilePhone' => 'required_without_all:psHomePhone,psOfficePhone',
            'psOfficePhone' => 'required_without_all:psHomePhone,psMobilePhone',
            //'psWorkplace' => 'required',
            'psEduInstitution' => 'required',
            'psDegreeQualification' => 'required',
            'psDegreeName' => 'required',
            'psDiplNo' => 'required',
            'psGraduationDate' => 'required|date',
            'psDegreeGPA' => 'required|numeric|min:2|max:6',
            'psDegreeGPADef' => 'required|numeric|min:2|max:6',
            'psForeignLanguage' => 'required',
            'g-recaptcha-response' => 'required|captcha'
        ]);

        $candidate = Candidate::create(array(
            'EGN' => Input::get('psUIN'),
            'name'=> Input::get('psFirstName'),
            'surname' => Input::get('psSurname'),
            'last_name' =>Input::get('psLastName'),
            'gender' => Input::get('psGender'),
            'citizenship' => Input::get('psCitizenship'),
            'birthplace' => Input::get('psBirthplace'),
            'home_address' => Input::get('psHomeAddress'),
            'permanent_address' => Input::get('psPermanentAddress'),
            'home_phone' => Input::get('psHomePhone'),
            'mobile_phone' => Input::get('psMobilePhone'),
            'office_phone' => Input::get('psOfficePhone'),
            'email' => Input::get('psEmail'),
            'workplace' => Input::get('psWorkplace'),
            'edu_institution_name' => Input::get('psEduInstitution'),
            'degree_qualification' => Input::get('psDegreeQualification'),
            'degree_name' => Input::get('psDegreeName'),
            'diploma_id' => Input::get('psDiplNo'),
            'graduation_date' => Input::get('psGraduationDate'),
            'degree_gpa' => Input::get('psDegreeGPA'),
            'degree_def_gpa' => Input::get('psDegreeGPADef'),
            'status' => 0,
            'foreign_language' => Input::get('psForeignLanguage'),
            'password' => bcrypt(Input::get('psPassword')),
            'diploma_id' => Input::get('psDiplNo')
        ));
        if($candidate)
        return view('forms.candidate_register')->with(array('mode'=>'success'));
        else return view('forms.candidate_register')->with(array('mode'=>'failure'));
    }

    public function createAdvisorForm(){
        return view('forms.advisor')->with(['title'=>Lang::get('frontend.register_advisor_title')]);
    }

    public function checkAdvisorEmail(Request $request){
        $this->validate($request,array(
            'email' => 'required|email',
            'phone' => 'required',
            'g-recaptcha-response' => 'required|captcha'
        ));
        $email_exists = true;
        $passwordSent = false;
        if(ScientificAdvisor::where('email',Input::get('email'))->count() != 1){
            $email_exists = false;
            AdvisorRegistrationCode::generate(Input::get('email'),Input::get('phone'));
            return redirect('/register/advisor/code');
        } else {
            //send password and/or password request
            $passwordSent = ScientificAdvisor::where('email',Input::get('email'))->first()->sendPassword();
        }
        return view('forms.advisor')->with(['title'=>Lang::get('frontend.register_advisor_title'),'exists'=>$email_exists, 'passwordSent' => $passwordSent, 'submitted'=>true]);
    }

    public function advisorCodeForm(){
        return view('forms.advisor')->with(['title'=>Lang::get('frontend.register_advisor_title'),'exists'=>false, 'passwordSent' => false, 'submitted'=>true]);
    }

    public function checkAdvisorCode(Request $request){
        $this->validate($request,array(
            'code' => 'required|exists:advisor_regcodes,code,approved,1'
        ));

        return redirect('register/advisor/code/'.Input::get('code'));
    }

    public function completeRegistrationForm($code){
        $codeobj = AdvisorRegistrationCode::where('code',$code)->where('approved',true)->first();
        if(!isset($codeobj)){
            return redirect('register/advisor');
        }
        return view('forms.advisor_register')->with(array('code'=>$codeobj));
    }

    public function completeRegistration($code, Request $request){
        $this->validate($request,[
            'saName' => 'required',
            'saLastName' => 'required',
            'saPhone' => 'required_without:saEmail',
            'saEmail' => 'required_without:saPhone'
        ]);

        $codeobj = AdvisorRegistrationCode::where('code',$code)->where('approved',true)->first();
        if(!isset($codeobj)){
            return redirect('register/advisor');
        }
        ScientificAdvisor::create([
            'title' =>Input::get('saTitle'),
            'name' => Input::get('saName'),
            'surname' => Input::get('saSurname'),
            'last_name' => Input::get('saLastName'),
            'workplace' => Input::get('saWorkplace'),
            'phone' => Input::get('saPhone'),
            'email' => $code->email
        ]);

        return view('forms.advisor_success');
    }

    public function candidateProfile(){
        return view('candidate_profile');
    }

    public function viewApplicationForm($id){
        $applicationForm = ApplicationForm::where('id',$id)->where('candidate_id',Helpers::getUser()->id)->first();
        if(!$applicationForm) return back();
        return view('application_form')->with(array('af'=>$applicationForm));
    }

    public function setPhdPassword(Request $request){
        $this->validate($request,array(
            'password' => 'required|min:6',
            'password2' => 'required|same:password'
        ));


        Helpers::getUser()->phd->password = bcrypt(Input::get('password'));
        Helpers::getUser()->phd->save();
        return back();
    }

    public function editCandidateForm(){
        return view('forms.candidate_edit')->with(array('candidate'=>Helpers::getUser()));
    }

    public function editCandidate(){

    }
}
