<?php

/*
|--------------------------------------------------------------------------
| Routes File
|--------------------------------------------------------------------------
|
| Here is where you will register all of the routes in an application.
| It's a breeze. Simply tell Laravel the URIs it should respond to
| and give it the controller to call when that URI is requested.
|
*/

Route::get('controller','Controller@getIndex');
/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| This route group applies the "web" middleware group to every route
| it contains. The "web" middleware group is defined in your HTTP
| kernel and includes session state, CSRF protection, and more.
|
*/

Route::group(['middleware' => ['web','languageswitcher']], function (){
    Route::get('/','FrontController@getIndex');
    Route::get('admission','AdmissionController@getIndex');
    Route::get('admission/view/{id}','AdmissionController@getCompetitionInfo');
    Route::get('information','FrontController@getInformation');
    Route::get('reports','ReportController@getIndex');
    Route::get('reports/by/{criteria}/{id?}','ReportController@getReport');

    Route::get('language/{locale}','LanguageController@switchLanguage');

    Route::get('register',function (){
        return redirect('register/candidate');
    });
    Route::get('register/candidate','UserController@createCandidateForm');
    Route::post('register/candidate','UserController@createCandidate');
    Route::get('register/advisor','UserController@createAdvisorForm');
    Route::post('register/advisor','UserController@checkAdvisorEmail');//->middleware(['GrahamCampbell\Throttle\Http\Middleware\ThrottleMiddleware:5,30']);
    Route::get('register/advisor/code','UserController@advisorCodeForm');
    Route::post('register/advisor/code','UserController@checkAdvisorCode');
    Route::get('register/advisor/code/{code}','UserController@completeRegistrationForm');
    Route::post('register/advisor/code/{code}','UserController@completeRegistration');


    Route::get('auth/login', 'Auth\AuthController@getLogin');
    Route::post('auth/login', 'Auth\AuthController@postLogin');
    Route::get('auth/login/advisor', 'Auth\AdvisorAuthController@getLogin');
    Route::post('auth/login/advisor', 'Auth\AdvisorAuthController@postLogin');
    Route::get('auth/logout/advisor', 'Auth\AdvisorAuthController@logout');
    Route::get('auth/login/candidate', 'Auth\CandidateAuthController@getLogin');
    Route::post('auth/login/candidate', 'Auth\CandidateAuthController@postLogin');
    Route::get('auth/logout/candidate', 'Auth\CandidateAuthController@logout');
    Route::get('auth/login/phdstudent', 'Auth\PhdStudentAuthController@getLogin');
    Route::post('auth/login/phdstudent', 'Auth\PhdStudentAuthController@postLogin');
    Route::get('auth/logout/phdstudent', 'Auth\PhdStudentAuthController@logout');
    Route::get('auth/logout', 'Auth\AuthController@logout');
    Route::get('admin/logout', 'Auth\AuthController@adminLogout');
    Route::get('admin', 'Admin\FrontController@getIndex');

    Route::get('files/download/{id}/{filename}','FileController@downloadFile');

    Route::get('rateexceeded',function (){
        return view('rateexceeded')->with(['title'=>\Illuminate\Support\Facades\Lang::get('frontend.msg_uhoh')]);
    });

    Route::get('confirm/exams/{id}','AdmissionController@confirmExamNotification');


});

Route::group(['middleware'=>['web','auth']],function(){

    Route::get('admin/faculties','Admin\FacultyController@getIndex');
    Route::get('admin/faculties/add', 'Admin\FacultyController@createForm');
    Route::post('admin/faculties/add', 'Admin\FacultyController@create');

    Route::get('admin/departments','Admin\DepartmentController@getIndex');
    Route::get('admin/departments/add','Admin\DepartmentController@createForm');
    Route::post('admin/departments/add','Admin\DepartmentController@create');

    Route::get('admin/educationareas','Admin\HigherEducationAreaController@getIndex');
    Route::get('admin/educationareas/add','Admin\HigherEducationAreaController@createForm');
    Route::post('admin/educationareas/add','Admin\HigherEducationAreaController@create');

    Route::get('admin/professionalareas','Admin\ProfessionalAreaController@getIndex');
    Route::get('admin/professionalareas/add','Admin\ProfessionalAreaController@createForm');
    Route::post('admin/professionalareas/add','Admin\ProfessionalAreaController@create');

    Route::get('admin/specialties','Admin\SpecialtyController@getIndex');
    Route::get('admin/specialties/add','Admin\SpecialtyController@createForm');
    Route::post('admin/specialties/add','Admin\SpecialtyController@create');
    Route::get('admin/specialties/json/pa/{code}','Admin\SpecialtyController@getByPA');

    Route::get('admin/phdstudents','Admin\PhdStudentController@getIndex');
    Route::get('admin/phdstudents/add','Admin\PhdStudentController@createForm');
    Route::post('admin/phdstudents/add','Admin\PhdStudentController@create');

    Route::get('admin/phdstudents/password/{id}',function($id){
        return view('admin.forms.password')->with(array(
            'affected' => \App\PhDStudent::findOrFail($id)
        ));
    });

    Route::post('admin/phdstudents/password/{id}','Admin\PhdStudentController@setPassword');

    Route::get('admin/reports/by/{type}', 'Admin\ReportController@showFormByType');
    Route::get('admin/reports/by/faculty/{id}/{download?}','Admin\ReportController@reportByFaculty');

    Route::get('admin/scientificadvisors','Admin\ScientificAdvisorsController@getIndex');
    Route::get('admin/scientificadvisors/add','Admin\ScientificAdvisorsController@createForm');
    Route::post('admin/scientificadvisors/add','Admin\ScientificAdvisorsController@create');
    Route::get('admin/scientificadvisors/registrations','Admin\ScientificAdvisorsController@getIndexRegcodes');
    Route::get('admin/scientificadvisors/registrations/approve/{id}','Admin\ScientificAdvisorsController@regApproveAndSend');
    Route::get('admin/scientificadvisors/registrations/justapprove/{id}','Admin\ScientificAdvisorsController@regApprove');
    Route::get('admin/scientificadvisors/view/{id}','Admin\ScientificAdvisorsController@view');

    Route::get('admin/scientificadvisors/password/{id}',function($id){
        return view('admin.forms.password')->with(array(
            'affected' => \App\ScientificAdvisor::findOrFail($id)
        ));
    });

    Route::post('admin/scientificadvisors/password/{id}','Admin\ScientificAdvisorsController@setPassword');

    Route::post('admin/scientificadvisors/json/search/{type}/{value}','Admin\ScientificAdvisorsController@jsonSearch');

    Route::get('admin/candidates','Admin\CandidateController@getIndex');
    Route::get('admin/candidates/add','Admin\CandidateController@createForm');
    Route::post('admin/candidates/add','Admin\CandidateController@create');
    Route::get('admin/candidates/view/{id}','Admin\CandidateController@view');

    Route::get('admin/competitions','Admin\CompetitionController@getIndex');
    Route::post('admin/competitions/approve','Admin\CompetitionController@approve');
    Route::post('admin/competitions/reject','Admin\CompetitionController@reject');
    Route::post('admin/competitions/setstatus/{id}','Admin\CompetitionController@setStatus');
    Route::get('admin/competitions/view/{id}','Admin\CompetitionController@view');
    Route::post('admin/competitions/attach','Admin\CompetitionController@attach');
    Route::post('admin/competitions/setfee','Admin\CompetitionController@setFee');
    
    Route::get('admin/admissions','Admin\AdmissionController@getIndex');
    Route::get('admin/admissions/add','Admin\AdmissionController@createForm');
    Route::post('admin/admissions/add','Admin\AdmissionController@create');

    Route::get('admin/applicationforms','Admin\ApplicationFormController@getIndex');
    Route::get('admin/applicationforms/view/{id}','Admin\ApplicationFormController@view');
    Route::post('admin/applicationforms/view/{id}','Admin\ApplicationFormController@enroll');
    Route::post('admin/applicationforms/setexams','Admin\ApplicationFormController@setExam');
    Route::post('admin/applicationforms/updategrades','Admin\ApplicationFormController@updateGrades');
    Route::get('admin/applicationforms/generateorder/{id}','Admin\ApplicationFormController@generateOrder');
    
    Route::post('admin/elastic/{index}','Admin\ElasticSearchController@getResult');

    Route::get('admin/phdstudents/view/{id}','Admin\PhdStudentController@view');
});

Route::group(['middleware'=>['web','auth.advisor','languageswitcher']],function (){
    Route::get ('advisor','AdvisorPanelController@getIndex');
    Route::get('advisor/competitions/create','AdvisorPanelController@createCompetitionForm');
    Route::post('advisor/competitions/create','AdvisorPanelController@createCompetition');
    Route::get('advisor/competitions/documentation/{id}','AdvisorPanelController@competitionDocumentationForm');
    Route::post('advisor/competitions/documentation/{id}','AdvisorPanelController@postCompetitionDocumentationForm');
    Route::get('advisor/competitions/view/{id}','AdvisorPanelController@getCompetition');
    Route::get('advisor/competitions/view/candidates/{id}','AdvisorPanelController@getCompetitionCandidates');
    Route::get('advisor/candidates/view/{id}','AdvisorPanelController@getApplicationForm');

    Route::get('advisor/specialties/json/pa/{code}','Admin\SpecialtyController@getByPA');
    Route::get('advisor/phdstudents/view/{id}','AdvisorPanelController@viewPhdStudent');
    Route::post('advisor/phdstudents/view/{id}/upload',function($id,\Illuminate\Http\Request $request){
        $app = app();
        $controller = $app->make('\App\Http\Controllers\FileController');
        return $controller->callAction('uploadPhdFile',array($id,\App\Helpers::getUser()->id,$request));
    });
});

Route::group(['middleware'=>['web','auth.candidate','languageswitcher']], function (){
    Route::get('admission/apply/{id}','AdmissionController@applicationForm');
    Route::post('admission/apply/{id}','AdmissionController@processApplication');

    Route::get('profile','UserController@candidateProfile');
    Route::get('profile/edit','UserController@editCandidateForm');
    Route::post('profile/edit','UserController@editCandidate');
    Route::get('profile/applicationform/{id}','UserController@viewApplicationForm');

    Route::post('phdpassword','UserController@setPhdPassword');
} );

Route::group(['middleware'=>['web','auth.phdstudent','languageswitcher']], function (){
    Route::get('phdstudent','PhdStudentController@getProfile');
    Route::post('phdstudent/upload',function(\Illuminate\Http\Request $request){
        $app = app();
        $controller = $app->make('\App\Http\Controllers\FileController');
        return $controller->callAction('uploadPhdFile',array(\App\Helpers::getUser()->id,0,$request));
    });
} );
