<?php

namespace App;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Foundation\Auth\User as Authenticatable;

class PhDStudent extends Authenticatable
{
    protected $table = 'phd_students';

    protected $fillable = array('EGN','name','surname','last_name','gender','citizenship','birthplace','home_address','permanent_address','home_phone','mobile_phone','office_phone','email','password','workplace','edu_institution_name','degree_qualification','degree_name','graduation_date','degree_gpa','degree_def_gpa','status','edu_form_id','finance_form_id','department_id','specialty_id','scientific_advisor','scientific_advisor_sec','foreign_language','order_document','order_document_date','enrollment_date','term_deadline_date','diploma_id','portfolio_link');

    public $timestamps = true;

    public function specialty(){
        return $this->belongsTo('App\Specialty','specialty_id','id');
    }

    public function department(){
        return $this->belongsTo('App\Department','department_id','id');
    }

    public function edu_form(){
        return $this->belongsTo('App\EduForm','edu_form_id','id');
    }

    public function finance_form(){
        return $this->belongsTo('App\FinanceForm','finance_form_id','id');
    }

    public function scientificAdvisor(){
        return $this->belongsTo('App\ScientificAdvisor','scientific_advisor','id');
    }

    public function secondaryScientificAdvisor(){
        return $this->belongsTo('App\ScientificAdvisor','scientific_advisor_sec','id');
    }

    public function degreeQualification(){
        return $this->belongsTo('App\DegreeQualification','degree_qualification','id');
    }

    public function candidate(){
        return $this->hasOne('App\Candidate','linked_phd','id');
    }

    public function files(){
        return $this->hasMany('App\FileRegistry','phdstudent_id','id');
    }

    public function getStatus(){
      switch($this->status){
          default:
              return '?!?';
          break;

          case '0':
              return 'зачислен';
              break;
      }
    }

    public function registerFile($filename,$type,$size,$description,$uploader,$utype){
        return FileRegistry::create(array(
            'filename' => Carbon::now()->day.Carbon::now()->month.Carbon::now()->year.'_'.Carbon::now()->hour.Carbon::now()->minute.Carbon::now()->second.'_'.$filename,
            'original_filename' => $filename,
            'type' => $type,
            'size' => $size,
            'document_type' => 'document',
            'phdstudent_id' => $this->id,
            'file_description' => $description,
            'uploader_id' => $uploader,
            'uploader_type' => $utype

        ));
    }
}
